# Changelog

## [0.5.2](https://github.com/bhklab/bhklab-project-template/compare/v0.5.1...v0.5.2) (2025-05-12)


### Bug Fixes

* dont lock ([2832d1c](https://github.com/bhklab/bhklab-project-template/commit/2832d1ced3268f962e6a43ff4fb6d69fca1a47b7))

## [0.5.1](https://github.com/bhklab/bhklab-project-template/compare/v0.5.0...v0.5.1) (2025-05-12)


### Bug Fixes

* move default ([f932f8c](https://github.com/bhklab/bhklab-project-template/commit/f932f8c04d134e903474c948beb2404ec721652d))

## [0.5.0](https://github.com/bhklab/bhklab-project-template/compare/v0.4.0...v0.5.0) (2025-05-12)


### Features

* Add BHKLab project template CLI tool ([#12](https://github.com/bhklab/bhklab-project-template/issues/12)) ([4209392](https://github.com/bhklab/bhklab-project-template/commit/4209392626923eb0147de6013367cebc1321e2e0))
* Add lockfile update step in release workflow ([daece9c](https://github.com/bhklab/bhklab-project-template/commit/daece9c356b5063c0ed183345d831caef5e54d96))

## [0.4.0](https://github.com/bhklab/bhklab-project-template/compare/v0.3.1...v0.4.0) (2025-05-10)


### Features

* update project_name and project_description placeholders for dynamic values ([ca80e5f](https://github.com/bhklab/bhklab-project-template/commit/ca80e5ff457e44a951589b8da5e72147883f2821))

## [0.3.1](https://github.com/bhklab/bhklab-project-template/compare/v0.3.0...v0.3.1) (2025-05-10)


### Bug Fixes

* ascii art ([3ca1013](https://github.com/bhklab/bhklab-project-template/commit/3ca1013311614640fa9dae48c482cf8c1f72009d))

## [0.3.0](https://github.com/bhklab/bhklab-project-template/compare/v0.2.0...v0.3.0) (2025-05-09)


### Features

* add release command for initial alpha version in project setup ([6988526](https://github.com/bhklab/bhklab-project-template/commit/6988526be15970a69d0d19612b9796963f5d3164))

## [0.2.0](https://github.com/bhklab/bhklab-project-template/compare/v0.1.0...v0.2.0) (2025-05-09)


### Features

* add support for multiple authors in project templates ([47e3ae8](https://github.com/bhklab/bhklab-project-template/commit/47e3ae847bfe41e025b7603ef6cb02fdd0ca8a33))
* enhance project generator messages and structure setup tasks ([f83c0cd](https://github.com/bhklab/bhklab-project-template/commit/f83c0cde76221e183797cab03509c34f8c18cfb9))
